@@ -14,7 +14,10 @@ patterns = [
     Path('collections', views.collections, name='collections'),
     Path('collections/{collection}/', views.collection, name='collection'),
     Path('collections/{collection}/new/', views.collection_new, name='collection_new'),
-    Path('collections/{collection}/{lookup}/', views.collection_obj, name='collection_obj')
+    Path('collections/{collection}/delete/', views.collection_del_all, name='collection_del_all'),
+    Path('collections/{collection}/json/', views.collection_download, name='collection_download'),
+    Path('collections/{collection}/{lookup}/', views.collection_obj, name='collection_obj'),
+    Path('collections/{collection}/{lookup}/delete/', views.collection_del, name='collection_del')
     
     
     
