@@ -36,6 +36,8 @@ def collection_obj(request):
     collection = request.params.get('collection')
     model_db = JsonDB(collection + '/')
     obj = model_db.model().get(id=lookup)
+    if 'json' in request.query:
+        return JsonResponse(request, obj.json())
     # print(model_db.model.property_cls())
         
     form = AdminForm(obj)
@@ -48,6 +50,8 @@ def collection_obj(request):
         obj.update(**data)
         obj.save()
     context = {}
+    context['lookup'] = lookup
+    context['collection'] = collection
     context['form'] = form
     return Render(request, 'admin/obj.html', context)
 
@@ -68,6 +72,32 @@ def collection_new(request):
         return Redirect(request, 'admin:collection_obj', collection=collection, lookup=f.id)
     return Render(request, 'admin/col_n.html', context)    
     
+def collection_del(request):
+    lookup = request.params.get('lookup')
+    collection = request.params.get('collection')
+    model_db = JsonDB(collection + '/')
+    obj = model_db.model().get(id=lookup)
+    obj.delete()
+    return Redirect(request, 'admin:collection', collection=collection)
+
+
+def collection_del_all(request):
+    lookup = request.params.get('lookup')
+    collection = request.params.get('collection')
+    model_db = JsonDB(collection + '/')
+    objs = model_db.model().all(model=True)
+    for obj in objs:
+        obj.delete()
+    return Redirect(request, 'admin:collection', collection=collection)
+
+
+def collection_download(request):
+    lookup = request.params.get('lookup')
+    collection = request.params.get('collection')
+    model_db = JsonDB(collection + '/')
+    objs = model_db.model().all(model=False)
+    print(objs)
+    return JsonResponse(request, objs)
 
 @login_required(path='admin:login')
 def index(request):
