@@ -143,7 +143,16 @@ class Request:
     def parse_qs(self):
         # print(self.environ)
         if self.method != 'POST':
-            # self.
+            qs = self.query_string.split('&')
+            self.query = {}
+            for q in qs:
+                v = None
+                k = q
+                if '=' in q:
+                    k,v = q.split('=')
+                self.query[k] = v    
+                    
+            
             return
         
         self.post = PostBody({})
